-- Wild Ones faction standing script
local spir = require "factions.standing.lib.pirate"
spir.init{
   fct = faction.get("Wild Ones"),
}
